/**
 * ============LICENSE_START=======================================================
 * org.onap.aai
 * ================================================================================
 * Copyright © 2024 Deutsche Telekom AG Intellectual Property. All rights reserved.
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */
package org.onap.aai.modelloader.distribution;

import java.util.concurrent.CountDownLatch;

import org.aspectj.lang.annotation.After;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.stereotype.Component;

import lombok.Getter;
import lombok.Setter;

@Aspect
@Getter
@Setter
@Component
/**
 * Aspect to asynchronously wait for the EventCallback being called after a distribution event from sdc was published
 */
public class EventCallbackAspect {

  private CountDownLatch countDownLatch;

  @After(
      "execution(* org.onap.aai.modelloader.notification.EventCallback.activateCallback(..))")
  private void afterEventCallbackCalled() {
    if (countDownLatch != null) {
      countDownLatch.countDown();
    }
  }
}